/*==============================================
   This file is a part of the QENet library.
         Copyright 2012 - Nathan Osman
==============================================*/

#include <QMessageBox>

#include "CMainWindow.h"
#include "ui_CMainWindow.h"

CMainWindow::CMainWindow(QWidget * parent)
    : QMainWindow(parent), ui(new Ui::CMainWindow), m_peer(NULL)
{
    ui->setupUi(this);

    m_host.create();
    connect(&m_host, SIGNAL(peerConnected(QENetPeer*,quint32)), SLOT(peerConnected(QENetPeer*)));
    connect(&m_host, SIGNAL(connectionFailed()),                SLOT(connectionFailed()));
}

CMainWindow::~CMainWindow()
{
    delete ui;
}

void CMainWindow::connectClicked()
{
    QENetAddress address;
    address.setPort(ui->hostPort->value());
    if(address.resolve(ui->host->text()))
    {
        ui->statusBar->showMessage(tr("Attempting connection to '%1'...").arg(ui->host->text()));
        ui->host->setEnabled(false);
        ui->hostPort->setEnabled(false);
        ui->connect->setEnabled(false);

        m_host.connectToPeer(address);
    }
    else
        QMessageBox::critical(this, tr("Error:"), tr("Unable to resolve host '%1'.").arg(ui->host->text()));
}

void CMainWindow::connectionFailed()
{
    QMessageBox::critical(this, tr("Error:"), tr("Unable to connect to '%1'.").arg(ui->host->text()));

    ui->statusBar->showMessage(tr("Connection failed."));
    ui->host->setEnabled(true);
    ui->hostPort->setEnabled(true);
    ui->connect->setEnabled(true);
}

void CMainWindow::peerConnected(QENetPeer * peer)
{
    m_peer = peer;

    ui->statusBar->showMessage(tr("Connected to '%1'.").arg(ui->host->text()));
    ui->contents->setEnabled(true);
    ui->reliable->setEnabled(true);
    ui->send->setEnabled(true);
}

void CMainWindow::sendClicked()
{
    QENetPacket packet(ui->contents->toPlainText().toUtf8());
    if(ui->reliable->isChecked())
        packet.setFlags(QENetPacket::Reliable);
    ui->contents->clear();
    m_peer->send(packet);
}
