/*==============================================
   This file is a part of the QENet library.
         Copyright 2012 - Nathan Osman
==============================================*/

#include <QMessageBox>

#include "CMainWindow.h"
#include "ui_CMainWindow.h"

CMainWindow::CMainWindow(QWidget * parent)
    : QMainWindow(parent), ui(new Ui::CMainWindow)
{
    ui->setupUi(this);

    connect(&m_host, SIGNAL(peerConnected(QENetPeer*,quint32)), SLOT(peerConnected(QENetPeer*)));
}

CMainWindow::~CMainWindow()
{
    delete ui;
}

void CMainWindow::listenClicked()
{
    if(m_host.create(QENetAddress(QENetAddress::HostAny, ui->listeningPort->value()), 0, 1))
    {
        ui->listeningPort->setEnabled(false);
        ui->listen->setEnabled(false);
    }
    else
        QMessageBox::critical(this, tr("Error:"), tr("Unable to listen on port %1.").arg(ui->listeningPort->value()));
}

void CMainWindow::packetReceived(QENetPacket packet, quint8 channel)
{
    ui->received->appendHtml(tr("<b>[Channel %1]</b>: %2").arg(channel).arg(QString(packet.data())));
}

void CMainWindow::peerConnected(QENetPeer * peer)
{
    /* Have the peer delete itself upon disconnect. */
    connect(peer, SIGNAL(disconnected(quint32)), peer, SLOT(deleteLater()));

    /* Also we want to display a message when the peer sends one. */
    connect(peer, SIGNAL(received(QENetPacket,quint8)), SLOT(packetReceived(QENetPacket,quint8)));
}
