/*==============================================
   This file is a part of the QENet library.
         Copyright 2012 - Nathan Osman
==============================================*/

#include <cstring>
#include <QENetAddress>
#include "QENetAddressPrivate.h"

QENetAddressPrivate::QENetAddressPrivate()
    : initialized(false)
{
    memset(&address, 0, sizeof(ENetAddress));
}

QENetAddress::QENetAddress()
    : d(new QENetAddressPrivate)
{
}

QENetAddress::QENetAddress(quint32 host, quint16 port)
    : d(new QENetAddressPrivate)
{
    d->address.host = host;
    d->address.port = port;
    d->initialized = true;
}

QENetAddress::QENetAddress(const QString & hostname, quint16 port)
    : d(new QENetAddressPrivate)
{
    resolve(hostname);
    d->address.port = port;
    d->initialized = true;
}

QENetAddress::QENetAddress(const QENetAddress & original)
    : d(new QENetAddressPrivate)
{
    *this = original;
}

QENetAddress::~QENetAddress()
{
    delete d;
}

bool QENetAddress::resolve(const QString & hostname)
{
    if(!enet_address_set_host(&d->address, qPrintable(hostname)))
        return d->initialized = true;

    return false;
}

QString QENetAddress::toString() const
{
    char ip[256];
    return (!enet_address_get_host_ip(&d->address, ip, 256))?QString(ip):QString();
}

QString QENetAddress::reverse() const
{
    char host[256];
    return (!enet_address_get_host(&d->address, host, 256))?QString(host):QString();
}

quint32 QENetAddress::host() const
{
    return d->address.host;
}

void QENetAddress::setHost(quint32 host)
{
    d->address.host = host;
    d->initialized = true;
}

quint16 QENetAddress::port() const
{
    return d->address.port;
}

void QENetAddress::setPort(quint16 port)
{
    d->address.port = port;
    d->initialized = true;
}

QENetAddress & QENetAddress::operator =(const QENetAddress & rhs)
{
    *d = *rhs.d;
    return *this;
}
