/*==============================================
   This file is a part of the QENet library.
         Copyright 2012 - Nathan Osman
==============================================*/

#include <QENetPeer>
#include "QENetPeerPrivate.h"

QENetPeerPrivate::QENetPeerPrivate()
    : peer(NULL)
{
}

QENetPeer::QENetPeer(QObject * parent)
    : QObject(parent), d(new QENetPeerPrivate)
{
}

QENetPeer::~QENetPeer()
{
    delete d;
}

void QENetPeer::disconnectFromPeer(quint32 reason)
{
    Q_ASSERT(d->peer);

    enet_peer_disconnect(d->peer, reason);
}

void QENetPeer::disconnectLater(quint32 reason)
{
    Q_ASSERT(d->peer);

    enet_peer_disconnect_later(d->peer, reason);
}

void QENetPeer::reset()
{
    Q_ASSERT(d->peer);

    enet_peer_reset(d->peer);
}

bool QENetPeer::send(const QENetPacket & packet, quint8 channel) const
{
    Q_ASSERT(d->peer);

    ENetPacket * p = enet_packet_create(qPrintable(packet.data()), packet.data().length(), packet.flags());
    return !enet_peer_send(d->peer, channel, p);
}

bool QENetPeer::receive(QENetPacket & packet, quint8 & channel)
{
    Q_ASSERT(d->peer);

    ENetPacket * p = enet_peer_receive(d->peer, &channel);
    if(p)
    {
        packet.setData(QByteArray(reinterpret_cast<const char *>(p->data), p->dataLength));
        packet.setFlags(p->flags);
    }

    return (p);
}

void QENetPeer::ping() const
{
    Q_ASSERT(d->peer);

    enet_peer_ping(d->peer);
}

QENetAddress QENetPeer::address() const
{
    Q_ASSERT(d->peer);

    return QENetAddress(d->peer->address.host, d->peer->address.port);
}
